%
%   Comodulogram analysis
%
%   BENESCO Lecture series on signal analysis
%   Mojtaba Bandarabadi
%   Inselspital, Bern, 5 May 2017
%   for any question send email to: m.bandarabadi@gmail.com
%

%% clean up and load data
clear; close all; clc

load('data_CFC.mat')

%% Comodulogram analysis
% define frequency for phase
stPh = 0.5:17.5;
edPh = stPh+1;
phaseFreq = [stPh' edPh'];

% define frequency for amplitude
stA = 10:10:240;
edA = stA+10;
ampFreq = [stA' edA'];

[comod, meanAmp] = f_comodulogram(signal, sampRate, phaseFreq, ampFreq);

%% Plot results of comodulogram analysis
figure('Position',[30,60,1000,280],'Color',[1 1 1]);

% comodulogram graph
subplot(131);
contourf(mean(phaseFreq,2),mean(ampFreq,2),comod',10,'lines','none');
c = colorbar;
c.Label.String = 'Modulation Index';
box off
title('comodulogram');
ylabel('amplitude frequency (Hz)');
xlabel('phase frequency (Hz)');
set(gca,'fontsize',12);

% Phase-amplitude distribution for highest MI value
subplot(132);
[rowsOfMaxes,colsOfMaxes] = find(comod==max(max(comod))); % find max MI
bar(10:20:360,meanAmp(rowsOfMaxes,:,colsOfMaxes),'k');
box off
xlim([0 360])
title('phase-amplitude histogram');
set(gca,'xtick',0:40:360)
xlabel('phase (degree)')
ylabel('norm. amplitude')
set(gca,'fontsize',12);

% Phase-amplitude distribution for the second highest MI value (above 100 Hz in our case)
subplot(133);
[rowsOfMaxes,colsOfMaxes] = find(comod==max(max(comod(:,10:end)))); % find max MI (above 100 Hz)
bar(10:20:360,meanAmp(rowsOfMaxes,:,colsOfMaxes),'k');
box off
xlim([0 360])
title('phase-amplitude histogram');
set(gca,'xtick',0:40:360)
xlabel('phase (degree)')
ylabel('norm. amplitude')
set(gca,'fontsize',12);
